CurveError

Enum CurveError 

pub enum CurveError {
    Overflow,
    ZeroInput,
    EmptyPool,
    InvalidFee,
    InsufficientLpSupply,
}
Errors returnable by every function in this crate.

Variants



Overflow

An arithmetic operation overflowed even at u128.



ZeroInput

Caller passed a zero amount where a positive amount is required.



EmptyPool

Pool reserves are zero and the operation requires a non-empty pool.



InvalidFee

fee_bps >= 10_000 (>=100%).



InsufficientLpSupply

LP burn amount exceeds total LP supply.